@@ -13,29 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
+import re
+import shlex
 import base64
 import datetime
-import shlex
-import re
-import os
+
+from libcloud.utils.py3 import b, httplib
+from libcloud.common.base import JsonResponse, ConnectionUserAndKey, KeyCertificateConnection
+from libcloud.common.types import InvalidCredsError
+from libcloud.container.base import Container, ContainerImage, ContainerDriver
+from libcloud.container.types import ContainerState
+from libcloud.container.providers import Provider
 
 try:
     import simplejson as json
 except Exception:
     import json
 
-from libcloud.utils.py3 import httplib
-from libcloud.utils.py3 import b
-
-from libcloud.common.base import JsonResponse, ConnectionUserAndKey
-from libcloud.common.base import KeyCertificateConnection
-from libcloud.common.types import InvalidCredsError
-
-from libcloud.container.base import Container, ContainerDriver, ContainerImage
-
-from libcloud.container.providers import Provider
-from libcloud.container.types import ContainerState
-
 
 VALID_RESPONSE_CODES = [
     httplib.OK,
@@ -100,10 +95,10 @@ class DockerException(Exception):
         self.args = (code, message)
 
     def __str__(self):
-        return "%s %s" % (self.code, self.message)
+        return "{} {}".format(self.code, self.message)
 
     def __repr__(self):
-        return "DockerException %s %s" % (self.code, self.message)
+        return "DockerException {} {}".format(self.code, self.message)
 
 
 class DockerConnection(ConnectionUserAndKey):
@@ -119,7 +114,7 @@ class DockerConnection(ConnectionUserAndKey):
         """
         headers["Content-Type"] = "application/json"
         if self.user_id and self.key:
-            user_b64 = base64.b64encode(b("%s:%s" % (self.user_id, self.key)))
+            user_b64 = base64.b64encode(b("{}:{}".format(self.user_id, self.key)))
             headers["Authorization"] = "Basic %s" % (user_b64.decode("utf-8"))
         return headers
 
@@ -140,7 +135,7 @@ class DockertlsConnection(KeyCertificateConnection):
         **kwargs,
     ):
 
-        super(DockertlsConnection, self).__init__(
+        super().__init__(
             key_file=key_file,
             cert_file=cert_file,
             secure=secure,
@@ -251,7 +246,7 @@ class DockerContainerDriver(ContainerDriver):
             if host.startswith(prefix):
                 host = host.strip(prefix)
 
-        super(DockerContainerDriver, self).__init__(
+        super().__init__(
             key=key,
             secret=secret,
             secure=secure,
@@ -269,8 +264,7 @@ class DockerContainerDriver(ContainerDriver):
             # libcloud will handle them through LibcloudHTTPSConnection
             if not (key_file and cert_file):
                 raise Exception(
-                    "Needs both private key file and "
-                    "certificate file for tls authentication"
+                    "Needs both private key file and " "certificate file for tls authentication"
                 )
 
         self.connection.secure = secure
@@ -300,7 +294,7 @@ class DockerContainerDriver(ContainerDriver):
         data = json.dumps(payload)
 
         result = self.connection.request(
-            "/v%s/images/create?fromImage=%s" % (self.version, path),
+            "/v{}/images/create?fromImage={}".format(self.version, path),
             data=data,
             method="POST",
         )
@@ -380,7 +374,7 @@ class DockerContainerDriver(ContainerDriver):
             ex = ""
         try:
             result = self.connection.request(
-                "/v%s/containers/json%s" % (self.version, ex)
+                "/v{}/containers/json{}".format(self.version, ex)
             ).object
         except Exception as exc:
             errno = getattr(exc, "errno", None)
@@ -501,11 +495,11 @@ class DockerContainerDriver(ContainerDriver):
         if start:
             if float(self._get_api_version()) > 1.22:
                 result = self.connection.request(
-                    "/v%s/containers/%s/start" % (self.version, id_), method="POST"
+                    "/v{}/containers/{}/start".format(self.version, id_), method="POST"
                 )
             else:
                 result = self.connection.request(
-                    "/v%s/containers/%s/start" % (self.version, id_),
+                    "/v{}/containers/{}/start".format(self.version, id_),
                     data=data,
                     method="POST",
                 )
@@ -521,9 +515,7 @@ class DockerContainerDriver(ContainerDriver):
 
         :rtype: :class:`libcloud.container.base.Container`
         """
-        result = self.connection.request(
-            "/v%s/containers/%s/json" % (self.version, id)
-        ).object
+        result = self.connection.request("/v{}/containers/{}/json".format(self.version, id)).object
 
         return self._to_container(result)
 
@@ -539,7 +531,7 @@ class DockerContainerDriver(ContainerDriver):
         """
         if float(self._get_api_version()) > 1.22:
             result = self.connection.request(
-                "/v%s/containers/%s/start" % (self.version, container.id), method="POST"
+                "/v{}/containers/{}/start".format(self.version, container.id), method="POST"
             )
         else:
             payload = {
@@ -548,7 +540,7 @@ class DockerContainerDriver(ContainerDriver):
             }
             data = json.dumps(payload)
             result = self.connection.request(
-                "/v%s/containers/%s/start" % (self.version, container.id),
+                "/v{}/containers/{}/start".format(self.version, container.id),
                 method="POST",
                 data=data,
             )
@@ -569,7 +561,7 @@ class DockerContainerDriver(ContainerDriver):
         :rtype: :class:`libcloud.container.base.Container`
         """
         result = self.connection.request(
-            "/v%s/containers/%s/stop" % (self.version, container.id), method="POST"
+            "/v{}/containers/{}/stop".format(self.version, container.id), method="POST"
         )
         if result.status in VALID_RESPONSE_CODES:
             return self.get_container(container.id)
@@ -589,7 +581,7 @@ class DockerContainerDriver(ContainerDriver):
         data = json.dumps({"t": 10})
         # number of seconds to wait before killing the container
         result = self.connection.request(
-            "/v%s/containers/%s/restart" % (self.version, container.id),
+            "/v{}/containers/{}/restart".format(self.version, container.id),
             data=data,
             method="POST",
         )
@@ -609,7 +601,7 @@ class DockerContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "/v%s/containers/%s" % (self.version, container.id), method="DELETE"
+            "/v{}/containers/{}".format(self.version, container.id), method="DELETE"
         )
         return result.status in VALID_RESPONSE_CODES
 
@@ -623,7 +615,7 @@ class DockerContainerDriver(ContainerDriver):
         :rtype: ``str``
         """
         result = self.connection.request(
-            "/v%s/containers/%s/top" % (self.version, container.id)
+            "/v{}/containers/{}/top".format(self.version, container.id)
         ).object
 
         return result
@@ -641,7 +633,7 @@ class DockerContainerDriver(ContainerDriver):
         :rtype: :class:`libcloud.container.base.Container`
         """
         result = self.connection.request(
-            "/v%s/containers/%s/rename?name=%s" % (self.version, container.id, name),
+            "/v{}/containers/{}/rename?name={}".format(self.version, container.id, name),
             method="POST",
         )
         if result.status in VALID_RESPONSE_CODES:
@@ -701,7 +693,7 @@ class DockerContainerDriver(ContainerDriver):
 
         term = term.replace(" ", "+")
         result = self.connection.request(
-            "/v%s/images/search?term=%s" % (self.version, term)
+            "/v{}/images/search?term={}".format(self.version, term)
         ).object
         images = []
         for image in result:
@@ -734,7 +726,7 @@ class DockerContainerDriver(ContainerDriver):
         :rtype: ``bool``
         """
         result = self.connection.request(
-            "/v%s/images/%s" % (self.version, image.name), method="DELETE"
+            "/v{}/images/{}".format(self.version, image.name), method="DELETE"
         )
         return result.status in VALID_RESPONSE_CODES
 
@@ -751,9 +743,7 @@ class DockerContainerDriver(ContainerDriver):
                 name = data.get("Id")
         state = data.get("State")
         if isinstance(state, dict):
-            status = data.get(
-                "Status", state.get("Status") if state is not None else None
-            )
+            status = data.get("Status", state.get("Status") if state is not None else None)
         else:
             status = data.get("Status")
         if "Exited" in status:
