@@ -15,8 +15,7 @@
 
 
 from libcloud.container.providers import Provider
-
-from libcloud.container.drivers.docker import DockerContainerDriver, DockerConnection
+from libcloud.container.drivers.docker import DockerConnection, DockerContainerDriver
 
 
 class JoyentContainerDriver(DockerContainerDriver):
@@ -46,7 +45,7 @@ class JoyentContainerDriver(DockerContainerDriver):
         cert_file=None,
     ):
 
-        super(JoyentContainerDriver, self).__init__(
+        super().__init__(
             key=key,
             secret=secret,
             secure=secure,
@@ -72,8 +71,7 @@ class JoyentContainerDriver(DockerContainerDriver):
             # libcloud will handle them through LibcloudHTTPSConnection
             if not (key_file and cert_file):
                 raise Exception(
-                    "Needs both private key file and "
-                    "certificate file for tls authentication"
+                    "Needs both private key file and " "certificate file for tls authentication"
                 )
             self.connection.key_file = key_file
             self.connection.cert_file = cert_file
