@@ -13,27 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from __future__ import with_statement
-
-from typing import Dict
-from typing import Iterator
-from typing import List
-from typing import Optional
-from typing import Union
-from typing import Type
-from typing import Any
 
 import datetime
+from typing import Any, Dict, List, Type, Union, Iterator, Optional
 
 from libcloud import __version__
-from libcloud.common.base import Connection
-from libcloud.common.base import ConnectionUserAndKey, BaseDriver
 from libcloud.dns.types import RecordType
+from libcloud.common.base import BaseDriver, Connection, ConnectionUserAndKey
 
 __all__ = ["Zone", "Record", "DNSDriver"]
 
 
-class Zone(object):
+class Zone:
     """
     DNS zone.
     """
@@ -79,9 +70,7 @@ class Zone(object):
 
     def create_record(self, name, type, data, extra=None):
         # type: (str, RecordType, str, Optional[dict]) -> Record
-        return self.driver.create_record(
-            name=name, zone=self, type=type, data=data, extra=extra
-        )
+        return self.driver.create_record(name=name, zone=self, type=type, data=data, extra=extra)
 
     def update(
         self,
@@ -91,9 +80,7 @@ class Zone(object):
         extra=None,  # type: Optional[dict]
     ):
         # type: (...) -> Zone
-        return self.driver.update_zone(
-            zone=self, domain=domain, type=type, ttl=ttl, extra=extra
-        )
+        return self.driver.update_zone(zone=self, domain=domain, type=type, ttl=ttl, extra=extra)
 
     def delete(self):
         # type: () -> bool
@@ -109,14 +96,14 @@ class Zone(object):
 
     def __repr__(self):
         # type: () -> str
-        return "<Zone: domain=%s, ttl=%s, provider=%s ...>" % (
+        return "<Zone: domain={}, ttl={}, provider={} ...>".format(
             self.domain,
             self.ttl,
             self.driver.name,
         )
 
 
-class Record(object):
+class Record:
     """
     Zone record / resource.
     """
@@ -174,9 +161,7 @@ class Record(object):
         extra=None,  # type: Optional[dict]
     ):
         # type: (...) -> Record
-        return self.driver.update_record(
-            record=self, name=name, type=type, data=data, extra=extra
-        )
+        return self.driver.update_record(record=self, name=name, type=type, data=data, extra=extra)
 
     def delete(self):
         # type: () -> bool
@@ -204,10 +189,13 @@ class Record(object):
     def __repr__(self):
         # type: () -> str
         zone = self.zone.domain if self.zone.domain else self.zone.id
-        return (
-            "<Record: zone=%s, name=%s, type=%s, data=%s, provider=%s, "
-            "ttl=%s ...>"
-            % (zone, self.name, self.type, self.data, self.driver.name, self.ttl)
+        return "<Record: zone=%s, name=%s, type=%s, data=%s, provider=%s, " "ttl=%s ...>" % (
+            zone,
+            self.name,
+            self.type,
+            self.data,
+            self.driver.name,
+            self.ttl,
         )
 
 
@@ -254,9 +242,7 @@ class DNSDriver(BaseDriver):
 
         :return: ``None``
         """
-        super(DNSDriver, self).__init__(
-            key=key, secret=secret, secure=secure, host=host, port=port, **kwargs
-        )
+        super().__init__(key=key, secret=secret, secure=secure, host=host, port=port, **kwargs)
 
     def list_record_types(self):
         # type: () -> List[RecordType]
@@ -498,8 +484,8 @@ class DNSDriver(BaseDriver):
         values = {"version": __version__, "date": date}
 
         lines.append("; Generated by Libcloud v%(version)s on %(date)s UTC" % values)
-        lines.append("$ORIGIN %(domain)s." % {"domain": zone.domain})
-        lines.append("$TTL %(domain_ttl)s\n" % {"domain_ttl": zone.ttl})
+        lines.append("$ORIGIN {domain}.".format(domain=zone.domain))
+        lines.append("$TTL {domain_ttl}\n".format(domain_ttl=zone.ttl))
 
         for record in records:
             line = self._get_bind_record_line(record=record)
@@ -539,10 +525,10 @@ class DNSDriver(BaseDriver):
         parts = []  # type: List[Any]
 
         if record.name:
-            name = "%(name)s.%(domain)s" % {
-                "name": record.name,
-                "domain": record.zone.domain,
-            }
+            name = "{name}.{domain}".format(
+                name=record.name,
+                domain=record.zone.domain,
+            )
         else:
             name = record.zone.domain
 
