@@ -13,17 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Type
-from typing import Union
 from types import ModuleType
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Type, Union
 
-from libcloud.dns.types import Provider
-from libcloud.dns.types import OLD_CONSTANT_TO_NEW_MAPPING
+from libcloud.dns.types import OLD_CONSTANT_TO_NEW_MAPPING, Provider
 from libcloud.common.providers import get_driver as _get_provider_driver
 from libcloud.common.providers import set_driver as _set_provider_driver
 
-
 if TYPE_CHECKING:
     # NOTE: This is needed to avoid having setup.py depend on requests
     from libcloud.dns.base import DNSDriver
@@ -79,6 +75,4 @@ def get_driver(provider):
 
 def set_driver(provider, module, klass):
     # type: (Union[Provider, str], ModuleType, type) -> Type[DNSDriver]
-    return _set_provider_driver(
-        drivers=DRIVERS, provider=provider, module=module, klass=klass
-    )
+    return _set_provider_driver(drivers=DRIVERS, provider=provider, module=module, klass=klass)
